--[[
MillHelp
Author: Michael Joseph Murray aka Lyte of Lothar(US)
$Revision: 102 $
$Date: 2010-11-01 20:35:54 +0000 (Mon, 01 Nov 2010) $
2.0.1
contact: codemaster2010 AT gmail DOT com

Copyright (c) 2007-2010 Michael J. Murray aka Lyte of Lothar(US)
All rights reserved unless otherwise explicitly stated.
]]

local INK_PER_GLYPH = 3
local PIGMENT_PER_INK = 2

local strformat = string.format
local strfind = string.find
local strsplit = strsplit

local fmtstring = "|cffffffff%s x%d (%s x%d)|r"

--glyphTable is a mapping of Glyph itemIDs to ink itemIDs
local glyphTable = {
	--		Death Knight	--
	--Prime Glyphs--
	["43542"] = "43126", -- Death and Decay
	["45804"] = "43122", -- Death Coil
	["43827"] = "43124", -- Death Strike
	["43543"] = "43122", -- Frost Strike
	["43534"] = "43126", -- Heart Strike
	["45806"] = "43124", -- Howling Blast
	["43546"] = "43122", -- Icy Touch
	["43547"] = "43126", -- Obliterate
	["43549"] = "43124", -- Raise Dead
	["43550"] = "43126", -- Rune Strike
	["43551"] = "43124", -- Scourge Strike
	--Major Glyphs--
	["43533"] = "43126", -- Anit-Magic Shell
	["43826"] = "43124", -- Blood Boil
	["43536"] = "43122", -- Bone Shield
	["43537"] = "43126", -- Chains of Ice
	["45799"] = "43124", -- Dancing Rune Weapon
	["43541"] = "43122", -- Death Grip
	["45800"] = "43124", -- Hungering Cold
	["43548"] = "43124", -- Pestilence
	["43553"] = "43124", -- Pillar of Frost
	["43825"] = "43124", -- Rune Tap
	["43552"] = "43126", -- Strangulate
	["43554"] = "43124", -- Vampiric Blood
	--Minor Glyphs--
	["43535"] = "43124", -- Blood Tap
	["43539"] = "43124", -- Death's Embrace
	["43544"] = "43124", -- Horn of Winter
	["43671"] = "43124", -- Path of Frost
	["43673"] = "43124", -- Raise Ally
	["43672"] = "43124", -- Resilient Grip
	--		Druid		--
	--Prime Glyphs--
	["45601"] = "43124", -- Berserk
	["40919"] = "43118", -- Insect Swarm
	["67484"] = "43124", -- Lacerate
	["40915"] = "43126", -- Lifebloom
	["40900"] = "43126", -- Mangle
	["40923"] = "43116", -- Moonfire
	["40912"] = "43126", -- Regrowth
	["40913"] = "39774", -- Rejuvenation
	["40902"] = "43120", -- Rip
	["45604"] = "43126", -- Savage Roar
	["40901"] = "43122", -- Shred
	["40916"] = "43120", -- Starfire
	["45603"] = "43126", -- Starsurge
	["40906"] = "43126", -- Swiftmend
	["67487"] = "43116", -- Tiger's Fury
	["40922"] = "39774", -- Wrath
	--Major Glyphs--
	["45623"] = "43120", -- Barkskin
	["40924"] = "43116", -- Entangling Roots
	["67485"] = "43116", -- Faerie Fire
	["67486"] = "43118", -- Feral Charge
	["48720"] = "39774", -- Ferocious Bite
	["44928"] = "43126", -- Focus
	["40896"] = "43124", -- Frenzied Regeneration
	["40914"] = "43116", -- Healing Touch
	["40920"] = "43126", -- Hurricane
	["40908"] = "43126", -- Innervate
	["40897"] = "39774", -- Maul
	["45622"] = "43122", -- Monsoon
	["40903"] = "43124", -- Rake
	["40909"] = "43118", -- Rebirth
	["40899"] = "43126", -- Solar Beam
	["40921"] = "43126", -- Starfall
	["43332"] = "39774", -- Thorns
	["45602"] = "43124", -- Wild Growth
	--Minor Glyphs--
	["43316"] = "43116", -- Aquatic Form
	["43334"] = "43118", -- Challenging Roar
	["43674"] = "43118", -- Dash
	["43335"] = "39774", -- of the Wild
	["44922"] = "43126", -- Typhoon
	["43331"] = "43116", -- Unburdened Rebirth
	--		Hunter		--
	--Prime Glyphs--
	["42897"] = "43118", -- Aimed Shot
	["42898"] = "43116", -- Arcane Shot
	["45625"] = "43124", -- Chimera Shot
	["45731"] = "43124", -- Explosive Shot
	["42915"] = "43126", -- Kill Command
	["45732"] = "43126", -- Kill Shot
	["42911"] = "43124", -- Rapid Fire
	["42912"] = "39774", -- Serpent Sting
	["42914"] = "43126", -- Steady Shot
	["42909"] = "43126", -- Dazzled Prey
	--Major Glyphs--
	["42902"] = "43126", -- Bestial Wrath
	["42901"] = "43126", -- Concussive Shot
	["42903"] = "43120", -- Deterrence
	["42904"] = "43120", -- Disengage
	["42905"] = "43122", -- Freezing Trap
	["42906"] = "43124", -- Ice Trap
	["42908"] = "43116", -- Immolation Trap
	["45733"] = "43118", -- Master's Call
	["42900"] = "43116", -- Mending
	["42907"] = "39774", -- Misdirection
	["45735"] = "39774", -- Raptor Strike
	["45734"] = "43116", -- Scatter Shot
	["42910"] = "43118", -- Silencing Shot
	["42913"] = "43126", -- Snake Trap
	["42899"] = "43126", -- Trap Launcher
	["42917"] = "43126", -- Wyvern Sting
	--Minor Glyphs--
	["43355"] = "43120", -- Aspect of the Pack
	["43351"] = "43118", -- Feign Death
	["43350"] = "39774", -- Mend Pet
	["43338"] = "39774", -- Revive Pet
	["43356"] = "39774", -- Scare Beast
	--		Mage		--
	--Prime Glyphs--
	["45738"] = "43124", -- Arcane Barrage
	["44955"] = "43124", -- Arcane Blast
	["42735"] = "43116", -- Arcane Missiles
	["42753"] = "43126", -- Cone of Cold
	["45736"] = "43124", -- Deep Freeze
	["42739"] = "43126", -- Fireball
	["42742"] = "43126", -- Frostbolt
	["44684"] = "43126", -- Frostfire
	["42745"] = "43126", -- Ice Lance
	["63539"] = "43126", -- Living Bomb
	["42749"] = "43124", -- Mage Armor
	["42751"] = "43126", -- Molten Armor
	["42743"] = "39774", -- Pyroblast
	--Major Glyphs--
	["42736"] = "43124", -- Arcane Power
	["44920"] = "43126", -- Blast Wave
	["42737"] = "43116", -- Blink
	["42754"] = "43126", -- Dragon's Breath
	["42738"] = "43118", -- Evocation
	["42741"] = "39774", -- Frost Nova
	["45740"] = "43120", -- Ice Barrier
	["42744"] = "43120", -- Ice Block
	["42746"] = "43118", -- Icy Veins
	["42748"] = "43126", -- Invisibility
	["50045"] = "43124", -- Mana Shield
	["42752"] = "43126", -- Polymorph
	["45737"] = "43124", -- Slow
	--Minor Glyphs--
	["43339"] = "39774", -- Arcane Brilliance
	--["63416"] = "", -- Armors
	["43359"] = "39774", -- Conjuring
	["45739"] = "43126", -- Mirror Image
	["43364"] = "39774", -- Slow Fall
	["43360"] = "43116", -- of the Monkey
	["43361"] = "39774", -- of the Penguin
	--		Paladin		--
	--Prime Glyphs--
	["41098"] = "43120", -- Crusader Strike
	["41106"] = "43116", -- Divine Favor
	["41103"] = "43122", -- Exorcism
	["45742"] = "43124", -- Hammer of the Righteous
	["45746"] = "43120", -- Holy Shock
	["41092"] = "43116", -- Judgement
	["41110"] = "43126", -- Seal of Insight
	["43869"] = "43126", -- Seal of Truth
	["45744"] = "43126", -- Shield of the Righteous
	["45743"] = "43124", -- Templar's Verdict
	["41105"] = "43124", -- Word of Glory
	--Major Glyphs--
	["45741"] = "43124", -- Beacon of Light
	["41104"] = "43118", -- Cleansing
	["41099"] = "43120", -- Consecration
	["43868"] = "43126", -- Dazing Shield
	["45745"] = "43126", -- Divine Plea
	["41096"] = "39774", -- Divine Protection
	["41108"] = "43116", -- Divinity
	["41101"] = "43126", -- Focused Shield
	["41095"] = "39774", -- Hammer of Justice
	["41097"] = "43126", -- Hammer of Wrath
	["43867"] = "43126", -- Holy Wrath
	["41109"] = "43126", -- Light of Dawn
	["41094"] = "43124", -- Rebuke
	["45747"] = "43116", -- Salvation
	["41107"] = "43126", -- Ascetic Crusader
	--["66918"] = "", -- the Long Word
	["41102"] = "43126", -- Turn Evil
	--Minor Glyphs--
	["43365"] = "43116", -- Blessing of Kings
	["43340"] = "39774", -- Blessing of Might
	["43366"] = "39774", -- Insight
	["43369"] = "43118", -- Justice
	["43367"] = "39774", -- Lay on Hands
	["41100"] = "43118", -- Righteousness
	["43368"] = "43116", -- Truth
	--		Priest		--
	--Prime Glyphs--
	["45753"] = "43124", -- Dispersion
	["42400"] = "43116", -- Flash Heal
	["45755"] = "43124", -- Guardian Spirit
	["42403"] = "43126", -- Lightwell
	["42415"] = "43118", -- Mind Flay
	["45756"] = "43124", -- Penance
	["42407"] = "43126", -- Power Word: Barrier
	["42408"] = "39774", -- Power Word: Shield
	["42409"] = "43126", -- Prayer of Healing
	["42411"] = "43118", -- Renew
	["42414"] = "43126", -- Shadow Word: Death
	["42406"] = "43124", -- Shadow Word: Pain
	--Major Glyphs--
	["42396"] = "43126", -- Circle of Healing
	["42397"] = "43120", -- Dispel Magic
	["45758"] = "43124", -- Divine Accuracy
	["42398"] = "43116", -- Fade
	["42399"] = "43122", -- Fear Ward
	["42401"] = "43124", -- Holy Nova
	["42402"] = "43116", -- Inner Fire
	["42404"] = "43126", -- Mass Dispel
	["45760"] = "43122", -- Pain Suppression
	["42405"] = "43126", -- Psychic Horror
	["42410"] = "39774", -- Psychic Scream
	["42412"] = "43126", -- Scourge Imprisonment
	["42416"] = "43120", -- Smite
	["42417"] = "43126", -- Spirit of Redemption
	["45757"] = "43126", -- Spirit Tap
	--Minor Glyphs--
	["43342"] = "39774", -- Fading
	["43371"] = "39774", -- Fortitude
	["43370"] = "43118", -- Levitate
	["43373"] = "43116", -- Shackle Undead
	["43372"] = "43118", -- Shadow Protection
	["43374"] = "43126", -- Shadowfiend
	--		Rogue		--
	--Prime Glyphs--
	["42954"] = "43126", -- Adrenaline Rush
	["42956"] = "39774", -- Backstab
	["42961"] = "43116", -- Eviscerate
	["42967"] = "43126", -- Hemorrhage
	["45762"] = "43124", -- Killing Spree
	["45768"] = "43122", -- Mutilate
	["42965"] = "43126", -- Revealing Strike
	["42969"] = "43126", -- Rupture
	["45764"] = "43124", -- Shadow Dance
	["42972"] = "43120", -- Sinister Strike
	["42973"] = "43120", -- Slice and Dice
	["45761"] = "43124", -- Vendetta
	--Major Glyphs--
	["42955"] = "43124", -- Ambush
	["42957"] = "43126", -- Blade Flurry
	["64493"] = "43118", -- Blind
	["45769"] = "43124", -- Cloak of Shadows
	["42958"] = "43126", -- Crippling Poison
	["42959"] = "43126", -- Deadly Throw
	["42960"] = "39774", -- Evasion
	["42962"] = "43116", -- Expose Armor
	["45766"] = "43126", -- Fan of Knives
	["42963"] = "43124", -- Feint
	["42964"] = "43116", -- Garrote
	["42966"] = "43118", -- Gouge
	["42971"] = "43126", -- Kick
	["42968"] = "43126", -- Preparation
	["42970"] = "43118", -- Sap
	["42974"] = "43122", -- Sprint
	["45767"] = "43126", -- Tricks of the Trade
	--["63420"] = "", -- Vanish
	--Minor Glyphs--
	["43379"] = "39774", -- Blurred Speed
	["43376"] = "43116", -- Distract
	["43377"] = "43116", -- Pick Lock
	["43343"] = "39774", -- Pick Pocket
	["43380"] = "43116", -- Poisons
	["43378"] = "43120", -- Safe Fall
	--		Shaman		--
	--Prime Glyphs--
	["45775"] = "43122", -- Earth Shield
	["41527"] = "43124", -- Earthliving Weapon
	["45771"] = "43124", -- Feral Spirit
	["41529"] = "43126", -- Fire Elemental Totem
	["41531"] = "39774", -- Flame Shock
	["41532"] = "43116", -- Flametongue Weapon
	["41524"] = "43126", -- Lava Burst
	["41540"] = "43118", -- Lava Lash
	["41536"] = "43116", -- Lightning Bolt
	["45772"] = "43124", -- Riptide
	["41526"] = "43126", -- Shocking
	["41539"] = "43126", -- Stormstrike
	["41541"] = "43122", -- Water Shield
	["41542"] = "43124", -- Windfury Weapon
	--Major Glyphs--
	["41517"] = "43126", -- Chain Heal
	["41518"] = "43126", -- Chain Lightning
	["41552"] = "43126", -- Elemental Mastery
	["41530"] = "43116", -- Fire Nova
	["41547"] = "43118", -- Frost Shock
	["43725"] = "43116", -- Ghost Wolf
	["41538"] = "43126", -- Grounding Totem
	["41533"] = "43120", -- Healing Stream Totem
	["41534"] = "43126", -- Healing Wave
	["45777"] = "43126", -- Hex
	["41537"] = "39774", -- Lightning Shield
	["45776"] = "43122", -- Shamanistic Rage
	["45778"] = "39774", -- Stoneclaw Totem
	["45770"] = "43124", -- Thunder
	["41535"] = "43120", -- Totemic Recall
	--Minor Glyphs--
	["43381"] = "43118", -- Astral Recall
	["43385"] = "43118", -- Renewed Life
	["43386"] = "43116", -- Arctic Wolf
	["44923"] = "43126", -- Thunderstorm
	["43344"] = "43116", -- Water Breathing
	["43388"] = "43118", -- Water Walking
	--		Warlock		--
	--Prime Glyphs--
	["42456"] = "43126", -- Bane of Agony
	["45781"] = "43124", -- Chaos Bolt
	["42454"] = "43126", -- Conflagrate
	["42455"] = "39774", -- Corruption
	["42459"] = "43126", -- Felguard
	["45779"] = "43124", -- Haunt
	["42464"] = "43126", -- Immolate
	["42465"] = "43116", -- Imp
	["42453"] = "43124", -- Incinerate
	["50077"] = "43126", -- Lash of Pain
	["45780"] = "43124", -- Metamorphosis
	["42468"] = "43122", -- Shadowburn
	["42472"] = "43126", -- Unstable Affliction
	--Major Glyphs--
	["42457"] = "43126", -- Death Coil
	["45782"] = "43126", -- Demonic Circle
	["42458"] = "43116", -- Fear
	["42460"] = "43126", -- Felhunter
	["42462"] = "39774", -- Healthstone
	["42463"] = "43126", -- Howl of Terror
	["45785"] = "39774", -- Life Tap
	["42471"] = "43124", -- Seduction
	["42467"] = "43118", -- Shadow Bolt
	["45783"] = "43126", -- Shadowflame
	["45789"] = "43116", -- Soul Link
	["42466"] = "43120", -- Soul Swap
	["42470"] = "43120", -- Soulstone
	["42473"] = "43118", -- Voidwalker
	--Minor Glyphs--
	["43392"] = "43118", -- Exhaustion
	["43390"] = "39774", -- Drain Soul
	["43393"] = "43118", -- Enslave Demon
	["42461"] = "43116", -- Health Funnel
	["43391"] = "43116", -- Kilrogg
	["43394"] = "43126", -- Souls
	["43389"] = "43116", -- Unending Breath
	--		Warrior		--
	--Prime Glyphs--
	["45790"] = "43124", -- Bladestorm
	["43416"] = "43122", -- Bloodthirst
	["43415"] = "43126", -- Devastate
	["43421"] = "43126", -- Mortal Strike
	["43422"] = "43118", -- Overpower
	["43432"] = "43124", -- Raging Blow
	["43424"] = "43118", -- Revenge
	["43425"] = "43126", -- Shield Slam
	["43423"] = "43116", -- Slam
	--Major Glyphs--
	["43414"] = "43120", -- Cleaving
	["63481"] = "61978", -- Colossus Smash
	["67483"] = "43118", -- Death Wish
	["43418"] = "39774", -- Heroic Throw
	["67482"] = "43122", -- Intercept
	["43419"] = "43126", -- Intervene
	["43397"] = "39774", -- Long Charge
	["43417"] = "43116", -- Piercing Howl
	["43413"] = "39774", -- Rapid Charge
	["43430"] = "43126", -- Resonating Power
	["45797"] = "43116", -- Shield Wall
	["45792"] = "43124", -- Shockwave
	["45795"] = "43124", -- Spell Reflection
	["43427"] = "43116", -- Sunder Armor
	["43428"] = "43124", -- Sweeping Strikes
	["43399"] = "39774", -- Thunder Clap
	["43431"] = "43126", -- Victory Rush
	--Minor Glyphs--
	["43395"] = "39774", -- Battle
	["43396"] = "39774", -- Berserker Rage
	["43412"] = "43126", -- Bloody Healing
	["49084"] = "43126", -- Command
	["43398"] = "43116", -- Demoralizing Shout
	["43400"] = "43124", -- Enduring Victory
	["45793"] = "43120", -- Furious Sundering
	["45794"] = "43126", -- Intimidating Shout
}

--inkTable is a mapping of Ink itemIDs to pigment itemIDs
local inkTable = {
	["43120"] = "39340", --celestial ink (violet pigment)
	["43124"] = "39342", --ethereal ink (nether pigment)
	["43126"] = "39343", --ink of the sea (azure pigment)
	["43118"] = "39339", --jadefire ink (emerald pigment)
	["43116"] = "39338", --lion's ink (golden pigment)
	["39774"] = "39334", --midnight ink (dusky pigment)
	["43122"] = "39341", --shimmering ink (silvery pigment)
	["61978"] = "61979", --blackfallow ink (ashen pigment)
}

local getGlyphString = setmetatable({}, {
	__index = function(t, k)
		local ink = glyphTable[k]
		local pigment = inkTable[ink]
		
		--convert the itemIDs into localized names via GII
		local pigmentName = GetItemInfo(tonumber(pigment))
		local inkName = GetItemInfo(tonumber(ink))
		
		--make sure the names are actually returned
		if inkName == nil or pigmentName == nil then
			t[k] = "Updating Cache"
			return t[k]
		end
		
		t[k] = strformat(fmtstring, inkName, INK_PER_GLYPH, pigmentName, PIGMENT_PER_INK*INK_PER_GLYPH)
		return t[k]
	end
})

_G["MillHelp_Glyphs"] = {}
function MillHelp_Glyphs:ClearCachedTooltips()
	for k in pairs(getGlyphString) do
		getGlyphString[k] = nil
	end
end

local function AddGlyphInfo(frame, itemLink)
	local _, _, itemString = strfind(itemLink, "^|c%x+|H(.+)|h%[.+%]")
	if itemString then
		local _, itemID = strsplit(":", itemString)
		if itemID then
			--see if the itemID is a glyph
			if glyphTable[itemID] then
				frame:AddLine(getGlyphString[itemID])
			end
		end
	end
	
	frame:Show()
end

local function HookIt(tt)
	tt:HookScript("OnTooltipSetItem", function(self, ...)
		local itemLink = select(2, self:GetItem())
		if itemLink and GetItemInfo(itemLink) then
			AddGlyphInfo(self, itemLink)
		end
	end)
end

HookIt(GameTooltip)
HookIt(ItemRefTooltip)
